@@ -1,18 +1,20 @@
 /*
-  Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
+    Copyright (c) 2013-2016 Montel Laurent <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
+    This library is free software; you can redistribute it and/or modify it
+    under the terms of the GNU Library General Public License as published by
+    the Free Software Foundation; either version 2 of the License, or (at your
+    option) any later version.
 
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
+    This library is distributed in the hope that it will be useful, but WITHOUT
+    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
+    License for more details.
 
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+    You should have received a copy of the GNU Library General Public License
+    along with this library; see the file COPYING.LIB.  If not, write to the
+    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+    02110-1301, USA.
 */
 
 #ifndef MERGECONTACTSDIALOG_H
@@ -20,7 +22,6 @@
 
 #include <QDialog>
 #include <AkonadiCore/Item>
-#include <KConfigGroup>
 #include "job/mergecontacts.h"
 #include "kaddressbookmergelib_export.h"
 class QDialogButtonBox;
@@ -40,10 +41,9 @@ public:
     ~MergeContactsDialog();
 
     void setContacts(const Akonadi::Item::List &list);
-private Q_SLOTS:
+private:
     void slotCustomizeMergeContact(const Akonadi::Item::List &lst, MergeContacts::ConflictInformations conflictType, const Akonadi::Collection &col);
     void slotContactMerged(const Akonadi::Item &item);
-private:
     void readConfig();
     void writeConfig();
     QDialogButtonBox *mButtonBox;
