@@ -41,4 +41,9 @@ MessageComposer::PluginEditorInterface *ZoomTextPluginEditor::createInterface(KA
     return interface;
 }
 
+bool ZoomTextPluginEditor::hasPopupMenuSupport() const
+{
+    return false;
+}
+
 #include "zoomtextplugineditor.moc"
