@@ -31,9 +31,9 @@ public:
     ~ConfirmAddressPlugin();
 
     MessageComposer::PluginEditorCheckBeforeSendInterface *createInterface(QObject *parent) Q_DECL_OVERRIDE;
-    bool hasConfigureSupport() const Q_DECL_OVERRIDE;
+    bool hasConfigureDialog() const Q_DECL_OVERRIDE;
 
-    MessageComposer::PluginEditorCheckBeforeSendConfigureWidgetSetting createConfigureWidget(KIdentityManagement::IdentityManager *identityManager, QWidget *parent) const Q_DECL_OVERRIDE;
+    void showConfigureDialog(QWidget *parent) Q_DECL_OVERRIDE;
 };
 
 #endif // CONFIRMADDRESSPLUGIN_H
