@@ -53,7 +53,7 @@ void AntiVirusPluginInterfaceTest::shouldEmitActivatedSignal()
     AntiVirusPluginInterface interface;
     interface.createAction(new KActionCollection(this));
 
-    QSignalSpy spy1(&interface, SIGNAL(emitPluginActivated(PimCommon::GenericPluginInterface*)));
+    QSignalSpy spy1(&interface, SIGNAL(emitPluginActivated(PimCommon::AbstractGenericPluginInterface*)));
     interface.actionType().action()->trigger();
     QCOMPARE(spy1.count(), 1);
 }
