@@ -33,10 +33,9 @@ AttendeeSelector::AttendeeSelector(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18n("Select Attendees"));
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
     QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
     mainLayout->addWidget(mainWidget);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setDefault(true);
@@ -64,6 +63,7 @@ QStringList AttendeeSelector::attendees() const
 {
     QStringList rv;
     const int numberOfAttendee(ui.attendeeList->count());
+    rv.reserve(numberOfAttendee);
     for (int i = 0; i < numberOfAttendee; ++i) {
         const QString addr = ui.attendeeList->item(i)->text();
 
